@@ -1,4 +1,3 @@
-
 #' Installs Julia packages if needed
 #'
 #' @param ... strings of package names
@@ -74,7 +73,7 @@ BayesFluxR_setup <- function(pkg_check = TRUE, nthreads = 4, seed = NULL, env_pa
   JuliaCall::julia_assign(sym.env, env_path)
   JuliaCall::julia_command(sprintf("Pkg.activate(%s)", sym.env))
   # pkgs_needed <- list("https://github.com/enweg/BayesFlux.jl.git", "Flux", "Distributions", "Random")
-  pkgs_needed <- list("https://github.com/enweg/BayesFlux.jl.git#0774a36", "Flux", "Distributions", "Random")
+  pkgs_needed <- list("BayesFlux", "Flux", "Distributions", "Random", "DataFrames")
   if (pkg_check){
     do.call(.install_pkg, pkgs_needed)
   }
